==> credentials-1.25-sources.jar: com/cloudbees/plugins/credentials/domains/Messages.java <==
// CHECKSTYLE:OFF

package com.cloudbees.plugins.credentials.domains;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * URI scheme
     * 
     */
    public static String SchemeSpecification_DisplayName() {
        return holder.format("SchemeSpecification.DisplayName");
    }

    /**
     * URI scheme
     * 
     */
    public static Localizable _SchemeSpecification_DisplayName() {
        return new Localizable(holder, "SchemeSpecification.DisplayName");
    }

    /**
     * Hostname
     * 
     */
    public static String HostnameSpecification_DisplayName() {
        return holder.format("HostnameSpecification.DisplayName");
    }

    /**
     * Hostname
     * 
     */
    public static Localizable _HostnameSpecification_DisplayName() {
        return new Localizable(holder, "HostnameSpecification.DisplayName");
    }

    /**
     * URI path
     * 
     */
    public static String PathSpecification_DisplayName() {
        return holder.format("PathSpecification.DisplayName");
    }

    /**
     * URI path
     * 
     */
    public static Localizable _PathSpecification_DisplayName() {
        return new Localizable(holder, "PathSpecification.DisplayName");
    }

    /**
     * Hostname:port
     * 
     */
    public static String HostnamePortSpecification_DisplayName() {
        return holder.format("HostnamePortSpecification.DisplayName");
    }

    /**
     * Hostname:port
     * 
     */
    public static Localizable _HostnamePortSpecification_DisplayName() {
        return new Localizable(holder, "HostnamePortSpecification.DisplayName");
    }

}

==> credentials-2.1.16-sources.jar: com/cloudbees/plugins/credentials/domains/Messages.java <==
// CHECKSTYLE:OFF

package com.cloudbees.plugins.credentials.domains;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code SchemeSpecification.DisplayName}: {@code URI scheme}.
     * 
     * @return
     *     {@code URI scheme}
     */
    public static String SchemeSpecification_DisplayName() {
        return holder.format("SchemeSpecification.DisplayName");
    }

    /**
     * Key {@code SchemeSpecification.DisplayName}: {@code URI scheme}.
     * 
     * @return
     *     {@code URI scheme}
     */
    public static Localizable _SchemeSpecification_DisplayName() {
        return new Localizable(holder, "SchemeSpecification.DisplayName");
    }

    /**
     * Key {@code HostnameSpecification.DisplayName}: {@code Hostname}.
     * 
     * @return
     *     {@code Hostname}
     */
    public static String HostnameSpecification_DisplayName() {
        return holder.format("HostnameSpecification.DisplayName");
    }

    /**
     * Key {@code HostnameSpecification.DisplayName}: {@code Hostname}.
     * 
     * @return
     *     {@code Hostname}
     */
    public static Localizable _HostnameSpecification_DisplayName() {
        return new Localizable(holder, "HostnameSpecification.DisplayName");
    }

    /**
     * Key {@code PathSpecification.DisplayName}: {@code URI path}.
     * 
     * @return
     *     {@code URI path}
     */
    public static String PathSpecification_DisplayName() {
        return holder.format("PathSpecification.DisplayName");
    }

    /**
     * Key {@code PathSpecification.DisplayName}: {@code URI path}.
     * 
     * @return
     *     {@code URI path}
     */
    public static Localizable _PathSpecification_DisplayName() {
        return new Localizable(holder, "PathSpecification.DisplayName");
    }

    /**
     * Key {@code HostnamePortSpecification.DisplayName}: {@code
     * Hostname:port}.
     * 
     * @return
     *     {@code Hostname:port}
     */
    public static String HostnamePortSpecification_DisplayName() {
        return holder.format("HostnamePortSpecification.DisplayName");
    }

    /**
     * Key {@code HostnamePortSpecification.DisplayName}: {@code
     * Hostname:port}.
     * 
     * @return
     *     {@code Hostname:port}
     */
    public static Localizable _HostnamePortSpecification_DisplayName() {
        return new Localizable(holder, "HostnamePortSpecification.DisplayName");
    }

}
